pub enum NormalGammaError {
MNotFinite {
m: f64,
},
RTooLow {
r: f64,
},
RNotFinite {
r: f64,
},
STooLow {
s: f64,
},
SNotFinite {
s: f64,
},
VTooLow {
v: f64,
},
VNotFinite {
v: f64,
},
}Variants
MNotFinite
The m parameter is infinite or NaN
RTooLow
The r parameter is less than or equal to zero
RNotFinite
The r parameter is infinite or NaN
STooLow
The s parameter is less than or equal to zero
SNotFinite
The s parameter is infinite or NaN
VTooLow
The v parameter is less than or equal to zero
VNotFinite
The v parameter is infinite or NaN