pub enum SkellamError {
Mu1TooLow {
mu_1: f64,
},
Mu1NotFinite {
mu_1: f64,
},
Mu2TooLow {
mu_2: f64,
},
Mu2NotFinite {
mu_2: f64,
},
}Variants
Mu1TooLow
The first rate parameter is less than or equal to zero
Mu1NotFinite
The first rate parameter is infinite or NaN
Mu2TooLow
The second rate parameter is less than or equal to zero
Mu2NotFinite
The second rate parameter is infinite or NaN