ConstantKernel

Struct ConstantKernel 

pub struct ConstantKernel { /* private fields */ }

Implementations

Source

impl ConstantKernel

pub fn new(value: f64) -> Result<ConstantKernel, KernelError>

Create a new kernel with the given constant value

pub fn new_unchecked(scale: f64) -> ConstantKernel

Create a new constant function kernel without checking the parameters