pub struct ConstantKernel { /* private fields */ }Implementations
Sourceimpl ConstantKernel
impl ConstantKernel
Sourcepub fn new(value: f64) -> Result<ConstantKernel, KernelError>
pub fn new(value: f64) -> Result<ConstantKernel, KernelError>
Create a new kernel with the given constant value
Sourcepub fn new_unchecked(scale: f64) -> ConstantKernel
pub fn new_unchecked(scale: f64) -> ConstantKernel
Create a new constant function kernel without checking the parameters